==> kernel-2.0-sources.jar: voxeet/com/sdk/core/abs/promises/GetConferenceStatus.java <==
package voxeet.com.sdk.core.abs.promises;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.google.common.base.Predicate;
import com.google.common.collect.Iterables;

import org.greenrobot.eventbus.EventBus;

import eu.codlab.simplepromise.Promise;
import eu.codlab.simplepromise.solve.PromiseSolver;
import eu.codlab.simplepromise.solve.Solver;
import retrofit2.Call;
import retrofit2.Response;
import voxeet.com.sdk.core.abs.AbstractConferenceSdkObservableProvider;
import voxeet.com.sdk.core.abs.AbstractConferenceSdkService;
import voxeet.com.sdk.core.abs.AbstractPromiseable;
import voxeet.com.sdk.core.abs.information.ConferenceInformation;
import voxeet.com.sdk.core.http.HttpCallback;
import voxeet.com.sdk.core.http.HttpHelper;
import voxeet.com.sdk.core.services.MediaService;
import voxeet.com.sdk.events.error.HttpException;
import voxeet.com.sdk.events.success.ConferenceUsersInvitedEvent;
import voxeet.com.sdk.events.success.GetConferenceStatusEvent;
import voxeet.com.sdk.models.ConferenceUserStatus;
import voxeet.com.sdk.models.impl.DefaultConferenceUser;

public class GetConferenceStatus extends AbstractPromiseable<ConferenceUsersInvitedEvent> {

    public GetConferenceStatus(@NonNull AbstractConferenceSdkService parent, @NonNull MediaService mediaService, @NonNull AbstractConferenceSdkObservableProvider provider, @Nullable ConferenceInformation information, @NonNull EventBus eventBus) {
        super(parent, mediaService, provider, information, eventBus);
    }

    @NonNull
    @Override
    public Promise<ConferenceUsersInvitedEvent> createPromise() {
        return new Promise<>(new PromiseSolver<ConferenceUsersInvitedEvent>() {
            @Override
            public void onCall(@NonNull final Solver<ConferenceUsersInvitedEvent> solver) {
                final Call<GetConferenceStatusEvent> user = getProvider().getConferenceStatusObservable(getInformation().getConference().getConferenceId());
                HttpHelper.enqueue(user, new HttpCallback<GetConferenceStatusEvent>() {
                    @Override
                    public void onSuccess(@NonNull GetConferenceStatusEvent object, @NonNull Response<GetConferenceStatusEvent> response) {
                        Iterable<DefaultConferenceUser> users = Iterables.filter(object.getConferenceUsers(), new Predicate<DefaultConferenceUser>() {
                            @Override
                            public boolean apply(DefaultConferenceUser input) {
                                return input.getStatus().equalsIgnoreCase(ConferenceUserStatus.CONNECTING.toString());
                            }
                        });

                        log("Successfully retrieved connecting users");

                        ConferenceUsersInvitedEvent event = new ConferenceUsersInvitedEvent(users);
                        getEventBus().post(event);
                        solver.resolve(event);
                    }

                    @Override
                    public void onFailure(@NonNull Throwable e, @Nullable Response<GetConferenceStatusEvent> response) {
                        HttpException.dumpErrorResponse(response);

                        log("Error while retrieving connecting users");

                        getEventBus().post(new ConferenceUsersInvitedEvent(null));
                        solver.reject(e);
                    }
                });
            }
        });
    }
}

==> kernel-2.0.4-sources.jar: voxeet/com/sdk/core/abs/promises/GetConferenceStatus.java <==
package voxeet.com.sdk.core.abs.promises;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import org.greenrobot.eventbus.EventBus;

import java.util.List;

import eu.codlab.simplepromise.Promise;
import eu.codlab.simplepromise.solve.PromiseSolver;
import eu.codlab.simplepromise.solve.Solver;
import retrofit2.Call;
import retrofit2.Response;
import voxeet.com.sdk.core.abs.AbstractConferenceSdkObservableProvider;
import voxeet.com.sdk.core.abs.AbstractConferenceSdkService;
import voxeet.com.sdk.core.abs.AbstractPromiseable;
import voxeet.com.sdk.core.abs.information.ConferenceInformation;
import voxeet.com.sdk.core.http.HttpCallback;
import voxeet.com.sdk.core.http.HttpHelper;
import voxeet.com.sdk.core.services.MediaService;
import voxeet.com.sdk.events.error.HttpException;
import voxeet.com.sdk.events.success.ConferenceUsersInvitedEvent;
import voxeet.com.sdk.events.success.GetConferenceStatusEvent;
import voxeet.com.sdk.models.ConferenceUserStatus;
import voxeet.com.sdk.models.impl.DefaultConferenceUser;
import voxeet.com.sdk.utils.ConferenceUtils;

public class GetConferenceStatus extends AbstractPromiseable<ConferenceUsersInvitedEvent> {

    public GetConferenceStatus(@NonNull AbstractConferenceSdkService parent, @NonNull MediaService mediaService, @NonNull AbstractConferenceSdkObservableProvider provider, @Nullable ConferenceInformation information, @NonNull EventBus eventBus) {
        super(parent, mediaService, provider, information, eventBus);
    }

    @NonNull
    @Override
    public Promise<ConferenceUsersInvitedEvent> createPromise() {
        return new Promise<>(new PromiseSolver<ConferenceUsersInvitedEvent>() {
            @Override
            public void onCall(@NonNull final Solver<ConferenceUsersInvitedEvent> solver) {
                final Call<GetConferenceStatusEvent> user = getProvider().getConferenceStatusObservable(getInformation().getConference().getConferenceId());
                HttpHelper.enqueue(user, new HttpCallback<GetConferenceStatusEvent>() {
                    @Override
                    public void onSuccess(@NonNull GetConferenceStatusEvent object, @NonNull Response<GetConferenceStatusEvent> response) {
                        List<DefaultConferenceUser> users = ConferenceUtils.getUserInState(object.getConferenceUsers(), ConferenceUserStatus.CONNECTING);

                        log("Successfully retrieved connecting users");

                        ConferenceUsersInvitedEvent event = new ConferenceUsersInvitedEvent(users);
                        getEventBus().post(event);
                        solver.resolve(event);
                    }

                    @Override
                    public void onFailure(@NonNull Throwable e, @Nullable Response<GetConferenceStatusEvent> response) {
                        HttpException.dumpErrorResponse(response);

                        log("Error while retrieving connecting users");

                        getEventBus().post(new ConferenceUsersInvitedEvent(null));
                        solver.reject(e);
                    }
                });
            }
        });
    }
}
